/*
 * Method which will be used to find the nearest atom from the residue list in our main data structure
 * Input:
 *  Data Structure pointer
 *  Integer representing the NanoShaper "nearest atom" input - note we should have already zero indexed this value when reading in the vert/face files
 */
static atom* find_nearest_atom(data_struct*, int);

/*
 * Method which will be used to find the nearest atom from the residue list in our main data structure
 * Input:
 *  Data Structure pointer
 *  Integer representing the NanoShaper "nearest atom" input - note we should have already zero indexed this value when reading in the vert/face files
 */
static atom* find_nearest_atom(data_struct* data, int nearest_atom_index){
  //start from the top
  int current_residue = 0;

  //while we can skip over the current residue
  while(data->residues[current_residue].natoms < nearest_atom_index){
    //decrement atom index BEFORE changing residue
    nearest_atom_index -= data->residues[current_residue].natoms;
    //change residue
    current_residue++;
  }

  return &data->residues[current_residue].atoms[nearest_atom_index];

}

/*
 * ASSUMPTION: Surface charge has already been computed for each vertex in the triangulation
 * IDEA: Run through the array of vertices one time and the residue/atom list; first to add each vertex's surface charge and increase an atom's vertex count
 * and second to divide per atom surface charge by the number of vertices.
 */
void compute_per_atom_surface_charge(data_struct* data){
  int i, j;
  //iterate over all triangles 
  for(i = 0; i < data->ntri; i++){
    triangle* current_triangle = &data->tris[i];
    //find the nearest atom for each triangle
    atom* nearest_atom = find_nearest_atom(data, current_triangle->nearest_atom_index);
    //add the corresponding triangles surface charge to the atom surface charge
    nearest_atom->surface_charge += current_triangle->surface_charge * current_triangle->area;
    //add the corresponding triangle surface area to the atom surface area
    nearest_atom->surface_area += current_triangle->area;
    //save the number of vertices for..
    nearest_atom->num_triangles++;
  }

  for(i = 0; i < data->nresidues; i++){
  	for(j = 0; j < data->residues[i].natoms; j++){
		if(data->residues[i].atoms[j].surface_area != 0) data->residues[i].atoms[j].surface_charge /= data->residues[i].atoms[j].surface_area;
	}
  }

  return;
}

/*
 * IDEA1: assuming we computed the number of vertices per atom and have the nanoshaper computed surface area somewhere, we could multiply the ratio of
 * number of atom vertices to total vertices by the surface area. I don't know if this will work, since I don't think there is a guarentee that
 * the triangulation is uniform; some atoms dont have a higher triangle density.
 * IDEA2: create a vertex list for each atom. Next is a choice that may or may not be accounted for through the optimization:
 *  to count a triangle towards a atom's surface area, given a vertex whose atom is that nearest atom, we must have [0, 1, 2] of the other vertices
 *  present in the triangle to count it.
 *  This choice will affect per atom surface area, though intuitively, to a less extent as triangulation density is increased.
 */
void compute_per_atom_surface_area(data_struct* data){
  //TODO
  return;
}
