#include <stdio.h>
#include <stdlib.h>
#include "file_io.h"

void prepare_structures(char *pqr_file_name, physical_structure *phys_struct, Triangulation_Method tri_method, triangulation_structure *tri_struct, model_parameters *md_param){
  /* read pqr file */
  /****************************/
  read_pqr(pqr_file_name, phys_struct);
  fflush(stderr);
  fflush(stdout);
  /* try to come up with the surface */
  /****************************/
  if(tri_method == MSMS){
    if(run_msms(phys_struct, md_param)){
      fprintf(stderr,"Warning: GEM needs the MSMS_EXECUTABLE_PATH environment\nvariable to be set in order to run msms directly.\nsearching for precomputed surfaces...\n");
    }
  }
  else if(tri_method == NANOSHAPER){
    if(run_nanoshaper(phys_struct, md_param)){
      fprintf(stderr,"Warning: GEM needs the NANOSHAPER_EXECUTABLE_PATH environment\nvariable to be set in order to run NanoShaper directly.\nsearching for precomputed surfaces...\n");
    }
  }
  else{
    fprintf(stderr, "Invalid triangulation method\n"); 
  }
  /* read the surface */
  /********************/
  read_vert_face(phys_struct->mol_name, &tri_struct->vertex_list, &tri_struct->triangle_list, &tri_struct->num_vertex, &tri_struct->num_triangles);
  if((tri_struct->num_vertex > 0) && (tri_struct->vertex_list != NULL)){
    fprintf(stdout,"Found surfaces, continuing.\n");
  }
  else{
    fprintf(stderr,"ERROR, could not find precomputed surfaces.\n");
    exit(-1);
  }
  fflush(stderr);
  fflush(stdout);
}
