/***************************************************************************
* GEM -- electrostatics calculations and visualization                     *
* Copyright (C) 2006 John C. Gordon, 2021 Dan Folescu                      *
*                                                                          *
* This program is free software; you can redistribute it and/or modify     *
* it under the terms of the GNU General Public License as published by     *
* the Free Software Foundation; either version 2 of the License, or        *
* (at your option) any later version.                                      *
*                                                                          *
* This program is distributed in the hope that it will be useful,          *
* but WITHOUT ANY WARRANTY; without even the implied warranty of           *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
* GNU General Public License for more details.                             *
*                                                                          *
* You should have received a copy of the GNU General Public License along  *
* with this program; if not, write to the Free Software Foundation, Inc.,  *
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.              *
***************************************************************************/

#include "file_io.h"
#include <stdio.h>
#include <stdbool.h>

/****************************************************************************
 * FUNCTION: write_xyzr  --writes an xyzr file for NanoShaper to read       *
 *                                                                          *
 * INPUTS: fname  -- name of the file to write                              *
 *                                                                          *
 * OUTPUTS: none                                                            *
 *                                                                          *
 * RETURNS: nothing                                                         *
 *                                                                          *
 ****************************************************************************/
void write_xyzr(char *fname, physical_structure *phys_struct)
{
   /* local variables */
   int i, j;
   FILE *fp;

   fp = fopen(fname, "w");

   bool addedSufficient = false;

   for (i = 0; i < phys_struct->num_residues; i++)
   {
      for (j = 0; j < phys_struct->residue_list[i]->num_atoms; j++)
      {
        if(!addedSufficient){
			fprintf(fp, "%f %f %f %c.%c%c%c%c%c%c\n", phys_struct->residue_list[i]->atom_list[j].x, phys_struct->residue_list[i]->atom_list[j].y, phys_struct->residue_list[i]->atom_list[j].z, 48, 48, 48, 48, 48, 48, 48);
			fprintf(fp, "%f %f %f %c.%c%c%c%c%c%c\n", phys_struct->residue_list[i]->atom_list[j].x, phys_struct->residue_list[i]->atom_list[j].y, phys_struct->residue_list[i]->atom_list[j].z, 48, 48, 48, 48, 48, 48, 48);
			fprintf(fp, "%f %f %f %c.%c%c%c%c%c%c\n", phys_struct->residue_list[i]->atom_list[j].x, phys_struct->residue_list[i]->atom_list[j].y, phys_struct->residue_list[i]->atom_list[j].z, 48, 48, 48, 48, 48, 48, 48);
			addedSufficient = true;
        }
        fprintf(fp, "%f\t%f\t%f\t%f\n",
                    phys_struct->residue_list[i]->atom_list[j].x,
                    phys_struct->residue_list[i]->atom_list[j].y,
                    phys_struct->residue_list[i]->atom_list[j].z,
                    phys_struct->residue_list[i]->atom_list[j].radius);
      }
   }

   fclose(fp);

}
