// ian Folescu 2021
#ifndef __READWRITE_H__
#define __READWRITE_H__

#include "structures.h"

typedef enum Triangulation_Method{MSMS,NANOSHAPER} Triangulation_Method;
typedef enum Write_Type{EFIELD,ASC} Write_Type;

/** 
 * opens and reads a pqr file 
 * returns pointer to a "physical_structure"
 **/
physical_structure *read_pqr(char*,physical_structure*);

/**
 * Read the file containing the lists of residues to be calculated.
 * Pick these out of the read physical structure, and return a list of these residues
**/
residue** read_residue_list(char*,physical_structure*);

/* reads in vertface style surface files */
void read_vert_face(char*,vertex**,triangle**,int*,int*);

/* writes an xyzr file for triangulation */
void write_xyzr(char*,physical_structure*);

/* run msms*/
int run_msms(physical_structure*,model_parameters*);

/* run nanoshaper */
int run_nanoshaper(physical_structure*,model_parameters*);

/**
 * triangulates the structure, based on the triangulation method parameter
 * returns pointer to a "triangulation_structure"
 **/
void prepare_structures(char*,physical_structure*,Triangulation_Method,triangulation_structure*,model_parameters*);

/* writes MSMS format file with specified per-vertex/per-triangle values */
void write_gvert_gface(char*,triangulation_structure*,Write_Type);

#endif
